THE FUR TRADE IN CANADA TO 1787 

J. E. Foster and D.R. Richeson 

Introduction 

     For nearly all regions of Canada, recorded history begins with the fur trade. The trade encompasses a kaleidoscope of experiences, ranging from the demi-heroic achievements of individuals to the machinations of empires headquartered in distant lands. Yet, in the end, the essence of the fur trade lies in the everyday lives of the people involved.

     Throughout Canada's history resources such as fish, fur, timber, grain and minerals have attracted the attention of various metropolitan centres. Individuals, business organizations and governments have invested heavily in the staple product resources of the Canadian hinterland, seeking the wealth, power and security that these resources promise. The duration and geographical scope of the fur trade, if not the numbers of people involved and the magnitude of its finances, made it the paramount resource exploitation activity in Canada's past. Its focus was the exchange of fur pelts for manufactured goods from Western Europe. Indian hunters trapped and processed the furs and transported them to key locations where, in exchange, traders from Western Europe offered goods and services attractive to the Indians. As agents of the different metropolitan centres and competing fur trade systems, traders sought waterways that allowed the movement of furs eastward and goods westward. Eventually they established communication routes across the entire northern half of the continent, reaching both the Arctic and Pacific Oceans. The legacy of this achievement, in part, is the extent of Canada's political boundaries today. Yet for all the importance of Western European metropolitan centres and their networks of influence in the North American hinterland, the cooperative participation of the North American native was equally necessary to ensure the success of the fur trade.

     The fur trade can also be viewed as the story of how and why individuals and communities adapted their cultural ways to changing environmental circumstances. Two peoples, the North American Indian and the Western European, initiated and sustained the fur trade to realize goals dictated by their particular cultural traditions. The original inhabitants of the continent had evolved distinct ways of life, admirably suited to the effective exploitation of the land's resources. Mostly they were nomadic hunters. Critical to their success were cultural ways emphasizing flexible responses to environmental change. With rare exception the Indian peoples welcomed the traders' goods and services, which seemed to facilitate the task of survival and enhance aspects of their traditional ways of life.

     Western European traders, principally British and French, also found it necessary to adapt to the circumstances of the trade. Necessity stimulated significant technological changes, particularly in terms of borrowing tools and techniques from the Indians. Less obvious were sociological and ideological changes arising out of the circumstances that provoked technological adaptations. For an understanding of Canada's fur trade experience, the lives of the participants are as important as the systems of influence and control emanating from a distant metropolis.

The Fur Trade to 1665 

     Experimentation was the key factor marking developments in the North American fur trade from the time of John Cabot's voyage of discovery in 1497 until the Royal Government of King Louis XIV of France intervened directly in the affairs of the colony of New France in 1663. Both Indians and Western Europeans experimented with the products to be acquired and the strategy most appropriate to their acquisition. Meanwhile, new roles and ways of life particular to the fur trade evolved in both the Indian and Western European communities.

     Initially both Western Europeans and Indians sampled various products of possible interest. For Western European entrepreneurs the fisheries proved highly successful, followed by the trade in fancy fur, pelts which were used with the hair attached to make coats, robes and fur trim. For economic and technological reasons timber was unpromising; nor were opportunities for a traffic in Indian slaves particularly attractive. No doubt the Indians of the region, the Micmac and Malecite of the Maritimes, the Beothuk in Newfoundland and the Montagnais on the north shore of the Gulf of St. Lawrence, were considering similar questions on first contact with Western Europeans. As nomadic hunters living in small, widely dispersed bands, they hunted game animals in the woodland regions during the winter months and migrated to the coasts in spring to exploit the resources of the shoreline. They found the metal tools of the fishermen to be most functional; later, items such as cloth and guns proved useful.

     Neither the Indians nor the Western Europeans were strangers to trading or to raiding as means of acquiring goods. The encounter, in 1534, between Jacques Cartier and his ship's crew and a band of Micmac on the shore of Baie de Chaleur in the Gulf of St. Lawrence demonstrates that each party was aware of the other's goods and avidly sought to trade for them. The absence of women and children amongst the Micmac on these occasions reveals a lack of trust and a fear of violent clashes, however, both Indians and Western Europeans appeared to favour trading rather than raiding as the most effective strategy for acquiring goods.

     The significance of trading strategy is highlighted in the tragic history of the Beothuk of Newfoundland, who did not establish an enduring trading relationship with the fishermen. Contacts between the two were marked by thievery and violence on both sides. When coastal fishermen ventured inland up the various rivers to fish salmon, hunt and trap furs, the Beothuk emerged as competitors rather than necessary partners in the exploitation of these resources. The Beothuk also suffered raids by the Micmac of the adjacent Maritime regions. As a result of these continuing clashes, the Beothuk were extinct by the early years of the nineteenth century.

     A very different relationship emerged between the fishermen and the Micmac. Having decided upon trading alliances as the most effective means of acquiring useful Western European goods, the Micmac adapted their traditional ways to reflect the advantages and costs of fur trading. The French became predominant among the Western Europeans trading with the Micmac, and by the end of the sixteenth century the Indians came to accept the presence of land-based traders. A French trader, wishing to assure himself of the friendship of a particular band and thus their trade in furs, married a woman of the band. Establishing himself in a trading post he traveled extensively with his Indian relations. These traders and their mixed -blood sons became known as capitaines des sauvages. Both the French and the Micmac preferred dealing with each other through these men. As intermediaries or brokers between two cultures, the capitaines des sauvages appear to have been essential to the success of the land -based fur trade in the Maritimes and to subsequent political alliances that bound French and Indians in the region.

     Initially the fur trade emphasized fancy furs. When feltmakers in Western Europe learned that the inner layer of beaver fur, the "wool" or "duvet", removed from the pelt, produced the highest quality felt cloth, the staple fur trade arose. Hats made from this material, the famous "beaver hat", became fashionable for men and remained popular until the 1830s when the staple fur trade yielded pre-eminence once again to the fancy fur trade.

     As it developed in the second half of the sixteenth century, the staple fur trade no longer remained an adjunct of the fishe ries. Ships began visiting the east coast solely to acquire pelts. Staple fur was the primary interest but fancy fur, particularly low-bulk, high-value pelts such as mink, otter, fisher and marten, remained a very important secondary interest through -out the history of the staple fur trade. Beaver pelts worn by the Indians as coats or robes provided the best quality staple fur. The outer guard hairs of the pelt, which detracted from its value, were lost during wear, leaving the wool or duvet on a supple, well-tanned hide. In the felting process this castor gras d'hiver (greasy winter beaver) or coat beaver, could be handled with much less cost than the parchment beaver. In the pursuit of coat beaver French traders journeyed up the St. Lawrence River, seeking more distant bands with which to trade. At Tadoussac, where the Saguenay River flows into the St. Lawrence, an extensive summer trade with the Montagnais developed in the late sixteenth century.

     During the sixteenth century the Montagnais changed their role in the fur trade from hunters who traded furs occasionally with fishermen to middlemen in regular, annual contact with French traders. The Montagnais discouraged contact between their Indian neighbours and the French, preferring to trade European goods to the former in exchange for fur pelts, which they bartered to European traders at a substantial profit. Controlling the fur trade at Tadoussac, the Montagnais could restrict the flow of furs and encourage competing French traders to bid up the prices that they would pay for pelts. Eventually the material prosperity of the Montagnais attracted the notice of more distant bands. Some from as far away as the Great Lakes sought access to French goods through trade. Others, particularly the Mohawk of the Iroquois Confederacy, found raiding the means most appropriate for acquiring French goods. In response, the Montagnais strengthened their alliance with their Algonquin neighbours in the Ottawa Valley by allowing them direct access to French traders. This development in turn encouraged the French to push westward up the St. Lawrence River to build, in 1608, a permanent habitation at Qubec.

     Pierre du Gua, Sieur de Monts, a nobleman actively engaged in high-risk commercial ventures such as the summer trade at Tadoussac, obtained from the French government in 1603 a monopoly of the fur trade, in exchange for which he accepted responsibility for overseeing French interests in the area. Samuel de Champlain represented de Monts's interests in the fur trade. After establishing Qubec, Champlain saw the necessity of strengthening his trading alliance with the Algonquin. He learned quickly that in the regions around the Great Lakes trading alliances were political pacts as well as commercial agreements. Two victorious battles over the Mohawk in 1609 and 1610, in concert with the Algonquin and their allies, promoted French interests. Most importantly, the French came in contact with the Huron, who lived near Georgian Bay and were skillful traders and allies of the Algonquin.

     With the development of the French-Huron alliance, the Montagnais found their circumstances radically altered. On first contact with fishermen the Montagnais merely added Western European products to their own repertory of goods. Thus metal tools such as knives and hatchets supplemented tools of stone, bone or wood, cloth supplemented leather, and occasional European foods such as grains and dried fruits and vegetables supplemented the produce of the hunt. Initially such additions were not extensive, but as the Montagnais came into contact with traders on a predictable annual basis they abandoned items which demanded more energy to produce than they would expend acquiring equivalents through the fur trade. Rather than supplementing Indian goods, Western European goods began to replace them. The Montagnais began to gear their activities, not to production for subsistence but for a surplus. They required surplus furs to trade to the French for Western European goods and they became dependent upon these goods for survival. When circumstances deprived them of their role as middlemen, the Montagnais were forced to become hunters and trappers again. Having lost many of the skills associated with such a way of life, they found the transition made more difficult by a scarcity of fur and game resources. Starvation and epidemics exacerbated a deteriorating situation. The Montagnais never did recoup their position as middlemen in the fur trade and their unhappy experience was duplicated by many native peoples in the years to come.

     Following the first encounters between members of the Huron Confederacy and French traders at Qubec, both parties worked to strengthen their alliance. The Huron were admirably suited geographically and culturally to assume a cooperative intermediary role in the trade. As agriculturalists, they had a security of food supply not known to hunting peoples such as the Ottawa, Nipissing, and Algonquin living to the west, north and east of them. Since women produced much of the food in Huronia, adult males had much time to devote to raiding and trading activities. Extensive trade networks criss-crossed the Great Lakes region before the appearance of the French. Dealing principally in luxury products such as sea shells, native copper, pipestone and tobacco, pre-Columbian trade patterns involved the movement of corn northward from Huron lands in exchange for meat, furs and hides from the hunters of the Canadian Shield. This experience prepared the Huron to assume the role of middlemen in the St. Lawrence-Great Lakes trading system, linking French traders at Qubec and the northern hunters of the Shield. Members of the Iroquois Confederacy sought access to these same furs. Circumstances of geography, interband political relations and their own cultural traditions encouraged the Iroquois to favour raiding as the most effective means of acquiring them. By 1630 the fur resources of their own lands were no longer adequate. Supplied with guns and ammunition by British traders in the New England colonies and later by the Dutch in New Amsterdam, the Iroquois had the means of acquiring furs from others. Although Iroquois diplomacy failed to sever the French alliance with the Huron, this did not dissuade them from raiding throughout the Great Lakes region.

     In the period from the founding of Qubec to the destruction of Huronia in 1648-49, the French tried two tactics to increase their influence over their Huron trading partners. Jesuit missionaries attempted to establish themselves as a major institution in Huron life, while at the same time coureurs who conducted trade in the interior, frequently contrary to French government regulations, also served as "cultural brokers", men with an intimate knowledge of both cultures who could explain the ways of each to the other. After their unfruitful labours among dispersed bands of the nomadic Montagnais, Jesuit missionaries centred their efforts on the large villages of Huronia. Using fur traders to gain access to Huronia in the 1630s, the Jesuits for a long time enjoyed little success. But by the end of the decade their fortunes appeared to change, with increasing numbers of Indians apparently seeking conversion.

     European diseases apparently accompanied the Jesuit to Huronia, reducing the population within a few years by over half. In time, disease and material wealth derived from the fur trade proved socially and culturally disruptive. By contrast, in sophisticating and strengthening their Confederacy, the Iroquois, southern cousins of the Huron, appear to have minimized the disruptive aspects of the fur trade. Among the Huron, material wealth benefitted the traders and the eastern tribes of the Confederacy at the expense of the warriors and the western tribes. Social and political unrest followed, as fur trade wealth set individual interests against communal responsibilities. Such problems could be handled effectively, provided that institutions could integrate individual interests with community interests. In this task the Iroquois were successful, the Huron were not.

     Among the Huron, epidemics accentuated the problem, not only because they tended to strike down the elderly, the repository of traditional wisdom, but also because they led the Huron to question the efficacy of their traditional methods of preserving life in the face of competing "witchcraft". The Jesuit missionaries' religious message aggravated an unstable set of circumstances. Not only did the Jesuits challenge traditional practices and beliefs, but Christian converts tended to shun "pagan" rites. For traditionalist Hurons, this behaviour was more threatening culturally than the raids of the Iroquois. The Huron could not overcome the inertia of the individualizing trends stemming from fur trade wealth and accelerated by events and developments associated with the Jesuit mission. In 1648-49, the Huron Confederacy shattered into refugee remnants in the face of Iroquois attacks and the Jesuit mission in Huronia was destroyed with it.

     The failure of the Jesuits in Huronia highlighted the achievements of the coureurs de bois as a successful French response to the circumstances of the fur trade in the Great Lakes region. Individuals similar to the coureurs de bois, the trading captains, had appeared in the fur trade in the Maritime region. But it is with Champlain's decision, in 1610, to send the youth tienne Brl to travel with the Algonquin to their Huron allies that the story of the coureurs de bois begins to emerge with some clarity. Brl was not unique, others followed. These young men acquired not only a knowledge of their host's language but also a knowledge of trade routes, traders and customs associated with the conduct of the trade. Willing participants in the way of life of their hosts, they won widespread acceptance amongst the Indian peoples. Quickly they emerged as cultural brokers between the two parties to the fur trade, explaining the strange ways of each to the other, facilitating peaceful interchanges between them. The risks were such that some, like Brl, lost their lives. But the rewards promised to be extensive; material means and socio-political eminence in two worlds awaited them.

     Following the destruction of Huronia and the dispersal of the Huron traders, coureurs de bois were crucial to restructuring the St. Lawrence-Great Lakes trading system. In the face of constant raids by the Iroquois, Indians of the Shield and the Upper Great Lakes found it difficult to sustain the flow of furs to the French at Montral. In order to preserve the St. Lawrence-Great Lakes trading system, the French had to take charge of the transportation of furs and trade goods between Montral and the trade centres of the Upper Great Lakes. Increasingly French engags (indentured servants) were found in canoes penetrating the interior. As well, the bourgeois, or merchant-trader, accompanied his goods west to supervise trading operations at distant posts. But critical to the success of the trade was the role of the coureur de bois, seeking out new bands, introducing them to the traders and, through alliances, strengthening their ties with particular merchants. At times this work was done in opposition to the regulations of the colonial government. Frequently the roles of coureur de bois and bourgeois were combined in one person, the voyageur. In the 1650s Pierre Esprit Radisson and Mdard Chouart, Sieur des Groseilliers were such men.

     The trading adventures of Radisson and Groseilliers among the Cree living between the Great Lakes and Hudson Bay left a dual legacy. Throughout the St. Lawrence-Great Lakes trading system, practices they introduced matured over the next half century to elaborate a way of life associated with the fur trade. With increasing frequency the role of the coureur de bois was fulfilled by a mixed-blood who was a kinsman of the bourgeois in the trading post but married to a woman of a prominent family in the Indian band. It was he who led small trading parties en derouine -- a medieval French term suggesting the itinerant peddling of goods -- to the winter hunting and trapping grounds of the Indians. Other mixed-bloods in the fur trade tended to look to this man, the cultural broker, as representing a life-style and position of socio-political consequence to which they aspired. By the beginning of the eighteenth century the term coureur de bois was giving way to voyageur but his role in the fur trade remained as crucial as ever.

     The second legacy of Radisson and Groseilliers was the creation of the Hudson's Bay Company. As a result of their contacts with the Cree north of Lake Superior, Radisson and Groseilliers theorized that ships from Europe could come to the "back-door" of the trapping Indians, eliminating the expensive middlemen and the costly hazards of a transportation route plagued by rapid-filled rivers and Iroquois raiders. Encountering no encouragement among the merchants and officials of New France or the Mother Country, Radisson and Groseilliers took their idea to English courtiers who, after proving its feasibility with the voyages of the Eaglet and the Nonsuch, acquired a monopoly from the British King, Charles II, on May 2,1670. The advice of Radisson and Groseilliers was instrumental in determining the Hudson's Bay Company's initial successes in its relations with the Indians.

The Hudson Bay Fur Trading System, 1670 -1770 

     Two themes underlay the first century of the trading system rooted in the posts by Hudson Bay. The first was the adaptation of the French and Indian experience in the St. Lawrence-Great Lakes system to the circumstances of the trade at posts on Hudson Bay and, in succeeding years, the elaboration of this adaptive experience in the lives of Indians and Britishers. The second theme involved the adaptation of British traditions to the circumstances encountered in the coastal factories.

     The charter of the Hudson's Bay Company bestowed a "magnificent gift" upon the merchant adventurers of the London metropolis. Rupert's Land, the area drained by Hudson Bay, extended over one third of the land area of present day Canada. In its early years the Company based its "bottom of the Bay" operations at Fort Albany with a subsidiary post at Moose Factory. In later years the headquarters moved to York Factory on the west coast of Hudson Bay, with subsidiary posts at Forts Severn and Churchill. With the establishment of these trading centres, Indians in the region oriented themselves towards the coastal factories and away from the forts of the St. Lawrence-Great Lakes system.

     In response to the presence of British traders on Hudson Bay, the Cree of the Shield country, what is today northern Ontario, and their neighbours and allies to the southwest, the Assiniboine (termed the Stoney in modern Alberta), began a migration that eventually took some of their descendants to the foothills of the Rocky Mountains. Initially attracted southeastward by French traders, the Cree and Assiniboine turned northwest for both staple and fancy fur. With their birchbark canoes they were able to utilize the Saskatchewan and Churchill rivers westward beyond Lake Winnipeg. The fact that the North Saskatchewan River passed through the parkland of the Great Plains region facilitated their westward migration. As an ecological zone between the boreal forest to the north and the prairie to the south, the parkland combined the plant and animal resources of both environments. Thus the Cree and the Assiniboine found a larder, admirably suited to their lives as nomadic hunters, situated astride the upper portion of the principal communication route extending from the Rocky Mountains to York Factory.

     The Indians of Rupert's Land adapted their traditions to fulfil three distinct roles in the fur trade. At a distance from the coastal factories the furs were harvested by those Indians who functioned for part of the year as trappers. In addition to some Cree and Assiniboine bands there were the members of the Blackfoot Confederacy the Blackfoot, the Blood, the Peigan and the Atsina plus the Sarsi, the Beaver, the Chipewyan and other Athapaskan-speaking peoples towards the northwest. These trapping bands rarely if ever encountered British traders but they were very familiar with metal goods such as knives, hatchets and kettles. In time guns and ammunition would become available, as well as luxury items such as beads and tobacco. Trade contact between the trapping Indians and Hudson's Bay Company traders was achieved through Indians who fulfilled the role of middlemen. In the west the Cree and the Assiniboine controlled access to York Factory; to the north at Churchill the Cree and Chipewyan disputed control, and at the bottom of the Bay, Ojibwa and Cree both functioned as intermediaries.

     In the first half of the eighteenth century, the Cree and the Assiniboine of the Saskatchewan River region, constitute another useful example of the middleman role in the fur trade. This role was expressed chiefly in the trading activities of the "Upland" bands. In early spring these trading Indians moved from their wintering grounds in the parkland to the river banks where they built canoes and traded furs with neighbouring trapping bands. Guns for which the Cree had paid eight to twelve Made Beaver the previous summer at York Factory, and had used throughout the winter, were traded for between twenty-four and thirty Made Beaver. (Made Beaver was the "currency" of the Hudson Bay trading system in which all furs were valued in terms of one prime adult beaver pelt.) Other goods were traded at similar markups. With the breakup of the river ice the various trading chiefs gathered their followers to accompany them to York Factory. Leaving most of the women and children near the fishing lakes to the north of the North Saskatchewan River, the bands travelled downriver towards the post. Between the third week in June and the second week in July trading bands arrived, frequent -ly half-starved, for a stay lasting up to two weeks. Gun salutes, speeches of welcome, and exchanges of gifts marked their arrival. After a celebration of two or three days, on food and drink provided by the Hudson's Bay Company factor, trading began. Indians passed furs through a trade-shop window and received goods in return. Frequently the trading chief remained in the trading room to assure his followers that the Company was adhering to the trade standards agreed upon in the welcoming speeches. The annual trade fair ended with more speeches and gifts of food and drink to the Indians. On returning to their home territories in late summer or early autumn, they abandoned their canoes frost ruined the birchbark, gathered up their families and moved south to hunt buffalo. With the onset of cold weather, buffalo migrated from the prairie to the parkland and there the trading Indians hunted them until spring heralded arrangements for another journey to York Factory.

     A few Cree Indians were attracted to the coastal regions near the factories on Hudson Bay to function as "Homeguard" Indians. They made as many as four or five trips to the post in the space of a year. In addition to supplying "small furs" such as fisher, marten and mink, the Homeguard Cree supplied meat, leather, feathers and other "country produce" and served as guides and couriers to the post. As the region around the posts constituted a most inhospitable environment, life for the Homeguard had its dangers. In performing their various activities they frequently faced starvation and if word of their plight could not be carried to the post the entire band might die. Yet life for the Homeguard Cree had its rewards. On a per capita basis they consumed more trade goods than either the trapping or trading Indians. Their role as Homeguards ensured a supply of European goods unequalled in the fur trade.

     The various responses of the Indians, evident in the three fur trade roles, trapper, middleman and Homeguard, enabled the Company to conduct its trade from coastal factories. The trading Indians proved willing and able to handle the problems and costs associated with moving furs and goods between Indian trappers and Company traders. Travels into the interior by Henry Kelsey in 1691-92, William Stewart in 1717-18, Anthony Henday in 1754-55, Samuel Hearne in 1777-78 and others were not made to conduct trade. These expeditions sought information and contact with more distant bands of Indians to encourage them to brave the rigours of the journey to the coastal factories.

     From the inception of the Hudson's Bay Company until the fall of New France in 1763, the French posed the major threat to the Company's success. During the first quarter century the French hotly disputed the Company's presence on the shores of Hudson Bay. Numerous battles underlined the tactical brilliance of the French in carrying the fight by land and sea to the Company. Yet neither France nor New France could decide whether their interests required the cost in time, effort and expense to defeat the Company and occupy its posts. The difficulties of arctic navigation, plus the minimal importance of Hudson Bay furs in French economic development, created a distinct lack of enthusiasm in the Mother Country for arctic adventures. In New France the coterie of influential entrepreneurs emphasized the trade in parchment beaver southwest to the Illinois country and beyond. Even leading merchants who favoured expansion to the northwest, such as Charles Aubert de la Chesnaye and Charles Le Moyne, feared that a victory over the Hudson's Bay Company would saturate the market with coat beaver, creating an oversupply problem already apparent in the parchment beaver trade. Because of such indecision in strategic matters, the French failed to follow up their tactical successes with enduring results and the Company survived several setbacks until the Treaty of Utrecht restored all its posts in 1713. Conflict with the French led the Company to strengthen the defenses of its coastal factories which, in turn combined with the willingness of the trading Indians to absorb the costs of transportation, led to the development of the coast factory trading system. Critics of the Company called this policy "the sleep by the frozen sea".

     To regulate social relations among the men at the Company's trading posts, the directors of the Company and the men themselves emulated customs, usages and laws associated with the British naval tradition in the early modern historical period. These naval traditions reflected the hierarchy and authority practised in British households of the era and applied to a society consisting solely of adult males. While the Company and its officers and men imitated the British example, their circumstances in the coastal factories of Hudson Bay required adaptations. Traditions associated with social hierarchy and authority, however, appeared to prove functional in the new world. Adult males regulated their behaviour towards each other in terms of the reciprocal privileges and responsibilities associated with each rank. Status alone, however, was not the sole regulator of lives; merit permitted significant movement between ranks. During the eighteenth century most officers were recruited from the ranks of the tradesmen. The image that seemed to define appropriate behaviour was that of a "man of consequence". The individual who crowned the social hierarchy of "men of consequence" in the trading post was the post Governor or Chief Factor.His privileges included more and better food, drink, clothing and living quarters while his responsibilities included not only the profitability of the fur trade but the basic welfare of the inhabitants of the factory and members of the surrounding Homeguard bands. His manner and lifestyle became the epitome of the good life in the trading post. Even the Homeguard Cree came to recognize him as "Uckimow", the Patriarch.

     Officially the Hudson's Bay Company banned fraternization with the Indians except for officers at the time of trade. This regulation had a two-fold purpose: it was intended to prevent the development of private trade and to avoid unpleasant incidents that might prove disruptive to a peaceful fur trade. Rather than following the Company's nonfraternization directive, the men of the trading post appear to have regulated their social relations with the Homeguard Cree on the basis of customs associated with the naval tradition in Great Britain. In the trading post only the Governor or Chief Factor was permitted to have an Indian woman as a "country wife". For other officers and servants seeking family bonds in Rupert's Land it was possible only among the surrounding Homeguard Cree bands. Such an arrangement was acceptable to the Homeguard Cree, who perceived the value of having a relation in the trading post who had access to the storehouse. At the same time officers and servants who had families in Homeguard Cree bands depended upon adult male Homeguard Cree kinsmen to see to their families' interests during the extended periods when they could not leave the trading posts. When an officer or servant retired he could neither join his family nor have them accompany him back to Great Britain. One noteworthy result was that over the century 1670-1770 the Homeguard became a biologically mixed people, though culturally remaining Cree.

     In spite of effective opposition mounted by the French inland, the coast factory system of trade remained the policy of the Hudson's Bay Company. With practices derived from the traditions of the coureur de bois in the previous century, Canadien traders blanketed the region north of the Great Lakes. En derouine parties visited Indian bands in their trapping and hunting grounds, offering a selection of necessary trade goods. Yet the Hudson's Bay Company was slow to respond. It would abandon its century-old coastal factory trading policy only when it came to realize that the advantages of cheaper transportation costs were not sufficient to overcome the enterprising trading practices of its rivals in the St. Lawrence-Great Lakes trading system.

The St. Lawrence-Great Lakes 
Trading System, 1665-1763 

     By the 1660s the French government had shifted its view of the fur trade from that of a predominantly commercial enterprise to that of an instrument of imperial expansion. Because these uses of the fur trade, as administered by local merchants and government officials, meshed admirably with Indian concepts of their own political and economic interests, the French enjoyed significant success. From a Western European perspective, the St. Lawrence-Great Lakes fur trade system enabled the French to dominate the interior of the continent, as well as to protect the infant settlement of New France from the expansionist energies of much more populous Anglo-American colonies to the south. The fur trade also played a significant role in the process whereby the "Canadien" emerged culturally distinct from the "French" in North America.

     Initially the Royal Government saw the fur trade as a major reason for the colony's vulnerability to Iroquois attack. With numbers of young men absent from the colony seeking their fortune in fur trade activities in the interior, New France lacked the socio-economic foundations necessary to resist attack effectively. The Royal Government initiated a compact settlement policy, restricting access to the interior and encouraging economic diversification and population growth.

     The personal interests of merchants involved in the fur trade were not in harmony with the compact settlement policy. The system of trading licenses was soon abused as merchants and government officials, for purposes of personal profit, cooperated in circumventing Royal Government dictates. A particularly flagrant example was the joint venture involving the Governor, Count Frontenac, and the merchant adventurer Rene-Robert Cavelier de La Salle. Such partnerships contributed to an increased flow of parchment beaver to French warehouses, eventually leading to the temporary collapse of the trade in beaver pelts in 1696. However, Canadien merchants and local officials, by circumventing official policy, succeeded in sustaining the system of fur trade alliances anchored on Montral and in maintaining the St. Lawrence-Great Lakes trading system as an instrument of French policy. In 1701 when the Royal Government abandoned its traditional policy in favour of one aimed at hemming the English into regions adjacent to the Atlantic coast and the shores of Hudson Bay, the St. Lawrence-Great Lakes trading system proved effective for promoting such a policy.

     Problems in logistics limited French expansion in the Northwest to the Lakehead region on Lake Superior. Supplies of corn and salt pork for the voyageurs ran out in the Lake Superior region, and the exigencies of time did not permit canoe brigades to hunt for their sustenance. The solution to the problem was achieved by Pierre Gaultier de Varennes, Sieur de la Verendrye, Commandant de poste du nord at Fort Kaministiquia from 1729 to 1743. With Royal Government support, acquired for exploration of the route to the Western Sea, he built a chain of posts westward from the Lakehead, following the water route through Rainy Lake and Lake of the Woods to the Winnipeg River and Lake Winnipeg. While these posts accepted furs from surrounding bands, they encouraged a trade in provisions as well. The wild rice of the region was admirably suited to the needs of the fur trade; harvested by the Indians in autumn, it could be stored and conveyed with ease. Dried meat and fish were traded as well and gardening was pursued with vigour at each post. La Verendrye's success in dealing with logistics enabled the St. Lawrence-Great Lakes trading system to expand into the Great Plains region. His subsequent journey to the agricultural villages of the Mandan Indians along the Missouri River proved unrewarding in terms both of the fur trade and of the search for the Western Sea. His successors emphasized efforts on the Saskatchewan River where opportunities for trading quality pelts, if not for discovering the Western Sea, were more obvious.

     The success of the St. Lawrence-Great Lakes trading system on the Saskatchewan River depended on a policy opposite to that of the Hudson's Bay Company. Rather than leaving the Indians to collect furs and transport them to coastal depots, Canadien traders, reflecting the history of their trading system since the destruction of Huronia, utilized small parties going en derouine to trade with the Indians. These parties gathered furs at central locations and with their own crews of engags transported them to Montral. The hazards and costs involved in this system of trade were significant. As a result Canadien traders emphasized low-bulk, high-value pelts, discouraging bear and wolf pelts, along with hides of the moose and buffalo. The canot du nord which replaced the canot du matre on northern waters carried only half the capacity of its eastern progenitor so Canadien traders could offer neither the number nor the variety of goods available at Hudson's Bay Company coastal factories. Yet in spite of the higher prices they were required to pay, it is apparent that the Indians of the interior welcomed the presence of the Canadien traders. Immediately the trade at the Hudson's Bay Company's York Factory dropped by two-fifths, and soon it would drop by over half. Convenience was a crucial factor in determining the trade habits of the Indians of the interior.

     No doubt some of the family bands of the Cree and Assiniboine trading Indians had misgivings concerning the presence of traders from New France. While traders offered convenience, they reduced the need for paramount trading chiefs by allowing individual band leaders to conduct their own trade negotiations. Some of the great trading chiefs continued their traditional role by carrying furs for which the Canadians had no use to the Hudson's Bay Company's coastal factories. Others, however, abandoned the trading role and turned to the plains and the exploitation of the buffalo on a year-round basis. The cultural evolution of some Cree and Assiniboine towards a "plains" way of life progressed slowly over the half century from 1730 to 1780. Unlike the Montagnais a century earlier, they continued to play a middleman role, not as traders but as politico- military alliance brokers, denying their enemies and permitting their friends access to weaponry derived from Western European products. When Cree and Assiniboine turned to year-round exploitation of the buffalo herds, their interests clashed with those of the Blackfoot Confederacy. The Blackfoot were in the process of acquiring the horse from peoples to the southwest and they were harassed by the better-armed Cree and Assiniboine who also wished to acquire the animal, a technologically superior means of exploiting the buffalo herds. To facilitate their purposes the Cree and Assiniboine sought to regulate the flow of weaponry from the trading posts.

     Critical to the success of the Great Lakes-St. Lawrence fur trade was the role of commercial and cultural "go-between" or broker. With the expansion of the trade to the Great Plains, a variety of persons filled this role which previously had been associated with the coureur de bois. To succeed, brokers required the graciousness of the diplomat, the showmanship of the performer, the curiosity of the adventurer and the survival instincts of the politician. In several instances Indian trade chiefs had performed this role admirably and would continue to do so. Some bourgeois had acquired such skills by serving as clerks or commis in their youth and leading trading parties en derouine. This activity was the coureur de bois role par excellence. Among the ranks of the engages were those who wished to be "their own boss" but remain in the fur trade. These gens du libre, or  freemen , took Indian wives and frequently functioned as brokers in relations with their wives' kinsmen. Both Canadien traders and Indians respected those who performed this coureur de bois role. For an ambitious commis the role could ensure the experience and social contacts with Indians and traders that facilitated a successful career as bourgeois in the Canadien community. For the freeman the role frequently guaranteed better prices for his goods when he traded at the trading post. When living among the Indians the role ensured the freeman a share of their goods as well as a place of respect in their councils. Such circumstances permitted some freemen to move easily between the socio-cultural worlds of the Indian and the Canadien, an ability unknown to many who were tied to unicultural worlds.

     Events in mid-eighteenth century Europe, manifesting themselves in North America as battles between conventional military forces, spelled the end of French dominance in the North American interior. The flow of trade goods to the pays d'en haut northwest of the Lakehead slowed to a trickle as the Seven Years' War unfolded in North America. Even before the battle on the Plains of Abraham in 1759, the Hudson's Bay Company believed that developments were vindicating its century-old coastside factory system of trade. In spite of criticism of its policy as the sleep by the frozen sea , the Company believed that, with the fall of Qubec and the end of the "French" threat, its traditional policy could continue for another hundred years. Within a decade it would be proved wrong.

Rival Traders in the Interior, 1763-1787 

     Merchants contracted as suppliers to victorious British forces occupying New France were among the first of the "pedlars" to attempt to revive the St. Lawrence-Great Lakes trading system. Dependent upon Canadien engages and commis, the pedlars quarrelled raucously with the Indians and among themselves. The events of Pontiac's uprising in 1763 demonstrated the ignorance of the British government and British merchants about conducting a fur trade along the Great Lakes. Yet within a few years the pedlars overcame their initial difficulties and penetrated beyond the Lakehead, threatening the Hudson's Bay Company's trade at its coastal factories.

     The pedlars conducted their trade through highly effective partnerships. A Montral partner was responsible for acquiring trade goods and shipping them to the interior and for marketing the previous year's trade in pelts through agents in London. In the interior one or more wintering partners, called bourgeois, were responsible for conducting the trade with the Indians. As the pedlars pressed westward and northward they found it useful to combine partnerships into syndics to provide sufficient logistical support for one wintering partner to further the interests of the others in more distant trading territories. One such syndic enabled Peter Pond, in 1778, to press northward beyond the Saskatchewan and Churchill River systems to the Athabasca River which eventually debouches through the Mackenzie River into the Arctic Ocean. The Athabasca country, centering on Fort Chipewyan, proved to be the "eldorado" of the fur trade, encompassing the trapping grounds of the Chipewyan Indians who, previously, had traded at the Hudson's Bay Company's Fort Churchill. The success of the Athabasca syndic paved the way for the formation in 1784 of an even larger syndic known as the North West Company. Three years later the North West Company emerged in a form that would survive for a generation and strongly influence Montral's commercial development.

     The Hudson's Bay Company initially attempted to counter the successes of the pedlars by dispatching "factory representatives" into the interior to encourage the Indians to ignore the pedlars and journey to the coastal factories. This tactic proved ineffective, and the Company in 1773 abandoned its coastside factory system of trade. The next year they established Cumberland House on Pine Lake, close to the Saskatchewan River above the Grand Rapids where the river entered Lake Winnipeg. Some thirty years earlier, at the bottom of the Bay, Henley House had been established on the Albany River, 240 kilometres above Fort Albany. At that time the directors of the Company did not choose to view the construction of the post as a betrayal of their traditional policy. Rather they saw it as a bastion to protect the Indians from the depredations of Canadien en derouine parties and to provision Indians on the last leg of their journey to Fort Albany. The sacking of Henley House in 1755 and in 1759 confirmed to the directors the danger and expense of inland trade. With the construction of Cumberland House, however, the Company abandoned its traditional policy at the bottom of the Bay and began to penetrate the interior there as well.

     As the Hudson's Bay Company moved inland one legacy of their "sleep by the frozen sea" became readily apparent. They lacked the technology necessary for travel on the inland waterways. Birch did not grow near the factories on the west coast of Hudson Bay, and bark had to be traded from Indians in the interior. Indian canoe makers who manufactured canoes for the Company emphasized their tradition of two-person craft rather than the six-person canot du nord of the rival North West Company. The "English" servants of the Company lacked the skills required to use canoes, and wars in Europe rendered it difficult to recruit young men who could be trained in these skills. Attempts to use trading Indians failed because they refused to accept the inferior social position of the "tripman" in the Company's service. During the fifteen year period that the Company required to solve its transportation problems the North West Company emerged paramount in the fur trade. It took another generation before the Hudson's Bay Company could challenge successfully its St. Lawrence-based rival.  

